import { AxiosInstance } from 'axios';
import { AxiosRequestConfig } from 'axios';
import { AxiosResponse } from 'axios';
import { PromiseResultFactory } from 'vue-composable';
import { Ref } from '@vue/composition-api';

declare interface AxiosReturn<TData> extends PromiseResultFactory<Promise<AxiosResponse<TData>>, [AxiosRequestConfig | string]> {
    readonly client: Ref<Readonly<AxiosInstance>>;
    readonly data: ComputedRef<TData | null>;
    readonly status: Ref<number | null>;
    readonly statusText: Ref<string | null>;
    cancel: (message?: string) => void;
    readonly isCancelled: Ref<boolean>;
    readonly cancelledMessage: Ref<string | null | undefined>;
}

declare type ComputedRef<T> = Readonly<Ref<Readonly<T>>>;

export declare function makeAxios(client: AxiosInstance, throwException?: boolean): {
    client: AxiosInstance;
    data: Readonly<import("@vue/composition-api/dist/reactivity/ref").Ref<Readonly<any>>>;
    status: Readonly<import("@vue/composition-api/dist/reactivity/ref").Ref<number>>;
    statusText: Readonly<import("@vue/composition-api/dist/reactivity/ref").Ref<string>>;
    cancel: (message?: string | undefined) => void;
    isCancelled: import("@vue/composition-api/dist/reactivity/ref").Ref<boolean>;
    cancelledMessage: import("@vue/composition-api/dist/reactivity/ref").Ref<string | null | undefined>;
    exec: (request: string | AxiosRequestConfig) => Promise<AxiosResponse<any> | undefined>;
    promise: import("@vue/reactivity").Ref<Promise<AxiosResponse<any>> | undefined>;
    result: import("@vue/reactivity").Ref<AxiosResponse<any> | null>;
    loading: import("@vue/reactivity").Ref<boolean>;
    error: import("@vue/reactivity").Ref<any>;
};

export declare function useAxios<TData = any>(throwException?: boolean): AxiosReturn<TData>;

export declare function useAxios<TData = any>(url: string, config?: AxiosRequestConfig, throwException?: boolean): AxiosReturn<TData>;

export declare function useAxios<TData = any>(url: string, throwException?: boolean): AxiosReturn<TData>;

export declare function useAxios<TData = any>(config?: AxiosRequestConfig, throwException?: boolean): AxiosReturn<TData>;

export { }
